;; Generated package description from pabbrev.el  -*- no-byte-compile: t -*-
(define-package "pabbrev" "4.2.2.0.20220722.151959" "Predictive abbreviation expansion" 'nil :commit "6de1b9e4b57b9e1a4d598d11f4476db9ee870637" :url "https://elpa.gnu.org/packages/pabbrev.html" :authors '(("Phillip Lord" . "phillip.lord@newcastle.ac.uk")) :maintainer '("Phillip Lord" . "phillip.lord@newcastle.ac.uk"))
